@@ -37,15 +37,16 @@ from .runners import (
     DefaultRunners,
 )
 from .site import (
-    Synchronize, GotoCurrentSiteQueue, ShowSiteSyncErrors,
+    Synchronize, GotoCurrentSiteQueue,
     WorkingSites, ExchangeSites,
     MinioFileUploader, MinioFileDownloader,
-    RequestRevisions, MultiRequestRevisions,
+    ExchangeSiteChoiceValue,
 )
 from .file import TrackedFile, Revision, DefaultFileMap
 from .kitsu import KitsuAPIWrapper, KitsuBindings, KitsuUsers, KitsuTasks
 from .dependency import DependencyTemplates
 from .mytasks import MyTasks
+from ..utils.flow.import_files import ImportFilesAction
 
 
 class LoginPageWidget(CustomPageWidget):
@@ -300,9 +301,6 @@ class Synchronization(flow.Object):
     _project = flow.Parent()
     synchronize_files = flow.Child(SynchronizeFiles)
     show_jobs = flow.Child(GotoCurrentSiteQueue)
-    show_errors = flow.Child(ShowSiteSyncErrors)
-    request_revisions = flow.Child(RequestRevisions)
-    multi_request_revisions = flow.Child(MultiRequestRevisions)
 
     def __init__(self, parent, name):
         super(Synchronization, self).__init__(parent, name)
@@ -437,12 +435,6 @@ class ProjectSettings(flow.Object):
         return self.hide_upload_after_publish.get().replace(' ', '').split(',')
 
 
-class ExchangeSiteChoiceValue(flow.values.ChoiceValue):
-
-    def choices(self):
-        return self.root().project().get_exchange_sites().mapped_names()
-
-
 class MultisiteConfig(flow.Object):
 
     ICON = ('icons.gui', 'sitemap')
@@ -567,6 +559,7 @@ class Project(flow.Object):
     log_out_action = flow.Child(LogOut).ui(label="Log out")
     goto_my_tasks = flow.Child(GoToMyTasks).ui(label="My Tasks")
     mytasks = flow.Child(MyTasks).ui(hidden=True)
+    import_files = flow.Child(ImportFilesAction)
 
     user = flow.Child(UserProfile)
     asset_lib = flow.Child(Assets).ui(expanded=True)
@@ -641,6 +634,9 @@ class Project(flow.Object):
             self.admin.multisites.current_site_name.get()
         )
     
+    def get_current_site_name(self):
+        return self.admin.multisites.current_site_name.get()
+    
     def get_working_site(self, name):
         """
         Returns the working site of the project
@@ -657,20 +653,14 @@ class Project(flow.Object):
             self.admin.multisites.exchange_site_name.get()
         ]
 
+    def set_exchange_site(self, name):
+        return self.admin.multisites.exchange_site_name.set(name)
+
     def get_working_sites(self):
         return self.admin.multisites.working_sites
 
     def get_exchange_sites(self):
         return self.admin.multisites.exchange_sites
-    
-    def get_site_names(self, short_names=False):
-        working_sites = self.get_working_sites()
-        exchange_sites = self.get_exchange_sites()
-
-        if short_names:
-            return working_sites.short_names() + exchange_sites.short_names()
-
-        return working_sites.mapped_names() + exchange_sites.mapped_names()
 
     def is_admin(self, username):
         try:
@@ -765,6 +755,10 @@ class Project(flow.Object):
         if context_name == "settings":
             return dict(
                 PROJECT=self.name(),
+                user=self.get_user_name(),
+                user_code=self.get_user().get_code(),
+                site=self.get_current_site_name(),
+                site_code=self.get_current_site().get_code(),
                 default_shot_layout_files="{sequence}_{shot}_layout.blend, {sequence}_{shot}_layout-movie.mov",
                 default_shot_animation_files="{sequence}_{shot}_animation.blend, {sequence}_{shot}_animation-movie.mov, {sequence}_{shot}_animation-export.abc",
                 default_asset_model_files="{asset_name}_model.blend, {asset_name}_model-movie.mov, {asset_name}_model-export.abc",
