@@ -15,15 +15,23 @@ class Asset(Entity):
 
     ICON = ('icons.flow', 'asset')
 
+    code = Property().ui(hidden=True)
+
     @classmethod
     def get_source_display(cls, oid):
         split = oid.split('/')
         indices = list(range(len(split) - 1, 2, -2))
         return ' · '.join([split[i] for i in reversed(indices)])
+    
+    def get_code(self):
+        return self.code.get() or self.name()
 
     def get_default_contextual_edits(self, context_name):
         if context_name == 'settings':
-            return dict(asset=self.name())
+            return dict(
+                asset=self.name(),
+                asset_code=self.get_code()
+            )
 
 
 class AssetCollection(EntityView):
@@ -97,9 +105,7 @@ class AssetType(Entity):
 
     ICON = ('icons.flow', 'asset_family')
 
-    asset_families = flow.Child(AssetFamilyCollection).injectable().ui(
-        expanded=True
-    )
+    asset_families = flow.Child(AssetFamilyCollection).injectable()
 
     @classmethod
     def get_source_display(cls, oid):
