@@ -423,6 +423,15 @@ class KitsuAPIWrapper(flow.Object):
         
         return result
     
+    def upload_asset_preview(self, asset_name, task_type_name, task_status_name, file_path, comment="", user_name=None):
+        asset = self.get_asset_data(asset_name)
+        result = False
+        
+        if asset is not None:
+            result = self.upload_preview(asset, task_type_name, task_status_name, file_path, comment, user_name)
+        
+        return result
+
     def upload_preview(self, kitsu_entity, task_type_name, task_status_name, file_path, comment="", user_name=None):
         # Get user
         user = self.get_user(user_name)
