@@ -14,13 +14,14 @@ from ..utils.kabaret.subprocess_manager.flow import RunAction
 from ..resources.icons import flow as flow_icons
 
 
-CHOICES = ["blend", "kra", "png", "jpg", "txt", "abc", "mov", "psd", "psb", "aep", "zip", "mp4", "fbx", "ai", "json", "jsx", "obj", "wav"]
+CHOICES = ["blend", "kra", "png", "jpg", "txt", "nk", "abc", "mov", "psd", "psb", "aep", "zip", "mp4", "fbx", "ai", "json", "jsx", "obj", "wav"]
 CHOICES_ICONS = {
             "blend": ("icons.libreflow", "blender"),
             "kra": ("icons.libreflow", "krita"),
             "png": ("icons.gui", "picture"),
             "jpg": ("icons.gui", "picture"),
             "txt": ('icons.gui', 'text-file-1'),
+            "nk": ("icons.libreflow", "nuke"),
             "abc": ("icons.flow", "alembic"),
             "aep": ("icons.libreflow", "afterfx"),
             "psd": ("icons.flow", "photoshop"),
@@ -208,6 +209,20 @@ class RV(EditFileRunner):
         return False
 
 
+class Nuke(EditFileRunner):
+
+    ICON = ("icons.libreflow", "nuke")
+    TAGS = [
+        "Compositing",
+        "Video Editing",
+        "VFX",
+    ]
+
+    @classmethod
+    def supported_extensions(cls):
+        return [".nk"]
+
+
 class PythonRunner(Runner):
 
     def executable(self):
