@@ -84,8 +84,8 @@ class Task(Entity):
         mapped_names = self.files.mapped_names()
         primary_files = []
         
-        for n in primary_names:
-            if n in mapped_names:
+        for n in mapped_names:
+            if n in primary_names or self.files[n].is_primary_file.get():
                 primary_files.append(self.files[n].oid())
         
         return primary_files
