@@ -1,6 +1,7 @@
 import os
 import sys
 import time
+import shutil
 from collections import defaultdict 
 from kabaret import flow
 from kabaret.flow_contextual_dict import get_contextual_dict
@@ -43,7 +44,7 @@ class SelectDefaultFileAction(flow.Action):
         return False
     
     def run(self, button):
-        if self._default_file.exists.get():
+        if self._default_file.exists.get() and not self._default_file.base_file_name.get():
             return
         
         self._default_file.create.set(
@@ -52,6 +53,100 @@ class SelectDefaultFileAction(flow.Action):
         self._map.touch()
 
 
+class ToggleUseBaseFileAction(flow.Action):
+
+    _file = flow.Parent()
+    _map = flow.Parent(2)
+
+    def needs_dialog(self):
+        return False
+    
+    def allow_context(self, context):
+        return False
+    
+    def run(self, button):
+        self._file.use_base_file.set(
+            self._file.exists.get()
+            or not self._file.use_base_file.get()
+        )
+        self._map.touch()
+
+
+class SelectBaseFileAction(flow.Action):
+
+    base_task = flow.SessionParam('')
+    base_file = flow.SessionParam('')
+
+    _file = flow.Parent()
+    _map = flow.Parent(2)
+
+    def needs_dialog(self):
+        self.base_task.set(self._file.from_task.get())
+        self.base_file.set(self._file.base_file_name.get())
+        return True
+    
+    def allow_context(self, context):
+        return False
+    
+    def get_buttons(self):
+        return ['Confirm', 'Cancel']
+    
+    def run(self, button):
+        if button == 'Cancel':
+            return
+        
+        self._file.from_task.set(self.base_task.get())
+        self._file.base_file_name.set(self.base_file.get())
+        self._file.use_base_file.set(self.base_task.get() and self.base_file.get())
+        self._file.create.set(True)
+        self._map.touch()
+
+
+class FileCreationOptionValue(flow.values.SessionValue):
+
+    DEFAULT_EDITOR = 'choice'
+    STRICT_CHOICES = False
+
+    _file = flow.Parent(2)
+
+    def choices(self):
+        choices = ['scratch']
+        base_file_name = self._file.base_file_name.get()
+
+        if base_file_name:
+            choices = [f'{self._file.from_task.get()}/{self._file.base_file_name.get()}'] + choices
+        
+        return choices
+    
+    def revert_to_default(self):
+        self.set(self.choices()[0])
+
+
+class SelectCreationOptionAction(flow.Action):
+
+    create_from = flow.SessionParam('scratch', FileCreationOptionValue)
+
+    _file = flow.Parent()
+    _map = flow.Parent(2)
+
+    def needs_dialog(self):
+        self.create_from.revert_to_default()
+        return True
+    
+    def allow_context(self, context):
+        return False
+    
+    def get_buttons(self):
+        return ['Confirm', 'Cancel']
+    
+    def run(self, button):
+        if button == 'Cancel':
+            return
+        
+        self._file.use_base_file.set(self.create_from.get() != 'scratch')
+        self._map.touch()
+
+
 class TaskDefaultFileViewItem(flow.SessionObject):
     """
     Describes a default file to be created in the list of
@@ -61,8 +156,14 @@ class TaskDefaultFileViewItem(flow.SessionObject):
     path_format = flow.Param()
     create      = flow.BoolParam()
     exists      = flow.BoolParam()
+    use_base_file = flow.BoolParam()
+    with flow.group('Base file settings'):
+        from_task = flow.Param()
+        base_file_name = flow.Param()
 
-    select      = flow.Child(SelectDefaultFileAction)
+    select                  = flow.Child(SelectDefaultFileAction)
+    select_creation_option  = flow.Child(SelectCreationOptionAction)
+    select_base_file        = flow.Child(SelectBaseFileAction)
 
 
 class TaskDefaultFileView(flow.DynamicMap):
@@ -86,19 +187,23 @@ class TaskDefaultFileView(flow.DynamicMap):
 
             self._cache = {}
 
-            for file_name, path_format, optional in default_files:
+            for n, (file_name, path_format, optional, use_base_file, from_task, base_file_name) in default_files.items():
                 n = file_name.replace('.', '_')
+                exists = self._file_exists(file_name)
                 self._cache[n] = dict(
                     file_name=file_name,
                     path_format=path_format,
-                    create=not optional,
-                    exists=self._file_exists(file_name)
+                    create=not optional and (not exists or base_file_name),
+                    exists=exists,
+                    use_base_file=use_base_file,
+                    from_task=from_task,
+                    base_file_name=base_file_name
                 )
         
         return self._cache.keys()
     
     def columns(self):
-        return ['Do create', 'File']
+        return ['Do create', 'File', 'From']
     
     def update(self):
         '''
@@ -114,23 +219,37 @@ class TaskDefaultFileView(flow.DynamicMap):
         child.path_format.set(self._cache[child.name()]['path_format'])
         child.create.set(self._cache[child.name()]['create'])
         child.exists.set(self._cache[child.name()]['exists'])
+        child.use_base_file.set(self._cache[child.name()]['use_base_file'])
+        child.from_task.set(self._cache[child.name()]['from_task'])
+        child.base_file_name.set(self._cache[child.name()]['base_file_name'])
     
     def _fill_row_cells(self, row, item):
         row['Do create'] = ''
         row['File'] = item.file_name.get()
+
+        if item.use_base_file.get():
+            row['From'] = f'{item.from_task.get()}/{item.base_file_name.get()}'
+        else:
+            row['From'] = ''
     
     def _fill_row_style(self, style, item, row):
         style['File_icon'] = get_icon(item.file_name.get())
-        style['Do create_activate_oid'] = item.select.oid()
 
-        if item.exists.get():
-            style['Do create_icon'] = ('icons.gui', 'check-box-empty-dark')
-            for col in self.columns():
-                style['%s_foreground-color' % col] = '#4e5255'
-        elif item.create.get():
+        if item.create.get():
             style['Do create_icon'] = ('icons.gui', 'check')
         else:
             style['Do create_icon'] = ('icons.gui', 'check-box-empty')
+
+        if item.exists.get():
+            style['From_activate_oid'] = item.select_base_file.oid()
+            style['File_foreground-color'] = '#4e5255'
+
+            if not item.base_file_name.get():
+                style['Do create_icon'] = ('icons.gui', 'check-box-empty-dark')
+        else:
+            style['From_activate_oid'] = item.select_creation_option.oid()
+        
+        style['Do create_activate_oid'] = item.select.oid()
     
     def _file_exists(self, file_name):
         name, ext = os.path.splitext(file_name)
@@ -138,14 +257,16 @@ class TaskDefaultFileView(flow.DynamicMap):
             exists = self._task.files.has_file(name, ext[1:])
         else:
             exists = self._task.files.has_folder(name)
+        
         return exists
 
 
 class CreateTaskDefaultFiles(flow.Action):
 
-    files = flow.Child(TaskDefaultFileView)
+    files = flow.Child(TaskDefaultFileView).ui(expanded=True)
 
     _task = flow.Parent()
+    _tasks = flow.Parent(2)
 
     def needs_dialog(self):
         self.message.set(f'<h2>Create {self._task.name()} default files</h2>')
@@ -160,26 +281,70 @@ class CreateTaskDefaultFiles(flow.Action):
             return
         
         for df in self.files.mapped_items():
-            if df.create.get() and not df.exists.get():
+            if df.create.get():
                 self._create_file(df)
     
     def _create_file(self, default_file):
         file_name = default_file.file_name.get()
         name, ext = os.path.splitext(file_name)
         if ext:
-            self._task.files.add_file(
-                name, ext[1:],
-                display_name=file_name,
-                tracked=True,
-                default_path_format=default_file.path_format.get()
-            )
+            f = None
+
+            if not default_file.exists.get():
+                f = self._task.files.add_file(
+                    name, ext[1:],
+                    display_name=file_name,
+                    tracked=True,
+                    default_path_format=default_file.path_format.get()
+                )
+                print('create default file')
+            else:
+                f = self._task.files[default_file.name()]
+            
+            if default_file.use_base_file.get():
+                from_task = default_file.from_task.get()
+                base_file_name = default_file.base_file_name.get()
+                base_name, base_ext = os.path.splitext(base_file_name)
+
+                if self._tasks.has_mapped_name(from_task):
+                    source_task = self._tasks[from_task]
+                    if source_task.files.has_file(base_name, base_ext[1:]):
+                        source_file = source_task.files[base_file_name.replace('.', '_')]
+                        source_revision = source_file.get_head_revision(sync_status="Available")
+                        print('grab head revision')
+                        r = f.add_revision(comment=f'from {base_file_name} {source_revision.name()}')
+                        revision_path = r.get_path()
+                        os.makedirs(os.path.dirname(revision_path), exist_ok=True)
+                        shutil.copy2(source_revision.get_path(), revision_path)
+                        print('copy base file')
         else:
-            self._task.files.add_folder(
-                name,
-                display_name=file_name,
-                tracked=True,
-                default_path_format=default_file.path_format.get()
-            )
+            f = None
+
+            if not default_file.exists.get():
+                f = self._task.files.add_folder(
+                    name,
+                    display_name=file_name,
+                    tracked=True,
+                    default_path_format=default_file.path_format.get()
+                )
+                print('create default folder')
+            else:
+                f = self._task.files[default_file.name()]
+            
+            if default_file.use_base_file.get():
+                from_task = default_file.from_task.get()
+                base_file_name = default_file.base_file_name.get()
+                
+                if self._tasks.has_mapped_name(from_task):
+                    source_task = self._tasks[from_task]
+
+                    if source_task.files.has_folder(base_file_name):
+                        source_file = source_task.files[base_file_name]
+                        source_revision = source_file.get_head_revision(sync_status="Available")
+                        r = f.add_revision(comment=f'from {base_file_name} {source_revision.name()}')
+                        revision_path = r.get_path()
+                        os.makedirs(os.path.dirname(revision_path), exist_ok=True)
+                        shutil.copytree(source_revision.get_path(), revision_path)
 
 
 # Default file presets
@@ -222,6 +387,11 @@ class CreateDefaultFileAction(flow.Action):
     enabled     = flow.SessionParam(True).ui(editor='bool')
     optional    = flow.SessionParam(False).ui(editor='bool')
     is_primary_file = flow.SessionParam(False).ui(editor='bool')
+    use_base_file = flow.SessionParam(False).ui(editor='bool')
+    with flow.group('Base file settings'):
+        from_task = flow.SessionParam('')
+        base_file_name = flow.SessionParam('')
+
     action_display_order = flow.SessionParam(dict).watched()
     visible_action_count = flow.SessionParam(0).watched()
 
@@ -255,6 +425,9 @@ class CreateDefaultFileAction(flow.Action):
         df.enabled.set(self.enabled.get())
         df.optional.set(self.optional.get())
         df.is_primary_file.set(self.is_primary_file.get())
+        df.use_base_file.set(self.use_base_file.get())
+        df.from_task.set(self.from_task.get())
+        df.base_file_name.set(self.base_file_name.get())
         df.action_display_order.set(self.action_display_order.get())
         df.visible_action_count.set(self.visible_action_count.get())
         df.path_format.set(path_format)
@@ -322,6 +495,11 @@ class DefaultFile(Entity):
     enabled              = Property().ui(editor='bool')
     optional             = Property().ui(editor='bool')
     is_primary_file      = Property().ui(editor='bool')
+    use_base_file        = Property().ui(editor='bool')
+    with flow.group('Base file settings'):
+        from_task = Property()
+        base_file_name = Property()
+
     action_display_order = Property()
     visible_action_count = Property()
 
@@ -493,6 +671,11 @@ class EditDefaultTaskFile(flow.Action):
     file_type   = flow.SessionParam(None, FileTypeValue)
     enabled     = flow.SessionParam().ui(editor='bool')
     optional    = flow.SessionParam().ui(editor='bool')
+    is_primary_file = flow.SessionParam().ui(editor='bool')
+    use_base_file = flow.SessionParam().ui(editor='bool')
+    with flow.group('Base file settings'):
+        from_task = flow.SessionParam()
+        base_file_name = flow.SessionParam()
     action_display_order = flow.SessionParam(dict)
     visible_action_count = flow.SessionParam(0)
 
@@ -506,6 +689,10 @@ class EditDefaultTaskFile(flow.Action):
         self.path_format.set(self._dft_file.path_format.get())
         self.enabled.set(self._dft_file.enabled.get())
         self.optional.set(self._dft_file.optional.get())
+        self.is_primary_file.set(self._dft_file.is_primary_file.get())
+        self.use_base_file.set(self._dft_file.use_base_file.get())
+        self.from_task.set(self._dft_file.from_task.get())
+        self.base_file_name.set(self._dft_file.base_file_name.get())
         self.action_display_order.set(self._dft_file.action_display_order.get())
         self.visible_action_count.set(self._dft_file.visible_action_count.get())
 
@@ -538,6 +725,10 @@ class EditDefaultTaskFile(flow.Action):
             dft_file.path_format.set(self.path_format.get())
             dft_file.enabled.set(self.enabled.get())
             dft_file.optional.set(self.optional.get())
+            dft_file.is_primary_file.set(self.is_primary_file.get())
+            dft_file.use_base_file.set(self.use_base_file.get())
+            dft_file.from_task.set(self.from_task.get())
+            dft_file.base_file_name.set(self.base_file_name.get())
             dft_file.action_display_order.set(self.action_display_order.get())
             dft_file.visible_action_count.set(self.visible_action_count.get())
 
@@ -586,6 +777,10 @@ class AddDefaultTaskFileEdit(flow.Action):
     enabled     = flow.SessionParam(True).ui(editor='bool')
     optional    = flow.SessionParam(False).ui(editor='bool')
     is_primary_file = flow.SessionParam(False).ui(editor='bool')
+    use_base_file = flow.SessionParam(False).ui(editor='bool')
+    with flow.group('Base file settings'):
+        from_task = flow.SessionParam('')
+        base_file_name = flow.SessionParam('')
 
     _map = flow.Parent()
     _task = flow.Parent(2)
@@ -615,6 +810,9 @@ class AddDefaultTaskFileEdit(flow.Action):
         df.enabled.set(self.enabled.get())
         df.optional.set(self.optional.get())
         df.is_primary_file.set(self.is_primary_file.get())
+        df.use_base_file.set(self.use_base_file.get())
+        df.from_task.set(self.from_task.get())
+        df.base_file_name.set(self.base_file_name.get())
 
         self._map.touch()
         self._mgr.default_files.touch()
@@ -649,6 +847,11 @@ class DefaultTaskFile(flow.SessionObject):
     enabled     = flow.BoolParam().ui(editable=False)
     optional    = flow.BoolParam().ui(editable=False)
     is_primary_file = flow.BoolParam().ui(editable=False)
+    use_base_file = flow.BoolParam().ui(editable=False)
+    with flow.group('Base file settings'):
+        from_task = flow.Param().ui(editable=False)
+        base_file_name = flow.Param().ui(editable=False)
+
     action_display_order = flow.Param().ui(editable=False)
     visible_action_count = flow.Param().ui(editable=False)
     is_edit     = flow.BoolParam().ui(editable=False)
@@ -713,6 +916,9 @@ class DefaultTaskFiles(flow.DynamicMap):
                     enabled=default_file.enabled.get(),
                     optional=default_file.optional.get(),
                     is_primary_file=default_file.is_primary_file.get(),
+                    use_base_file=default_file.use_base_file.get(),
+                    from_task=default_file.from_task.get(),
+                    base_file_name=default_file.base_file_name.get(),
                     action_display_order=action_display_order,
                     visible_action_count=visible_action_count
                 ))
@@ -734,6 +940,9 @@ class DefaultTaskFiles(flow.DynamicMap):
                     enabled=default_file.enabled.get(),
                     optional=default_file.optional.get(),
                     is_primary_file=default_file.is_primary_file.get(),
+                    use_base_file=default_file.use_base_file.get(),
+                    from_task=default_file.from_task.get(),
+                    base_file_name=default_file.base_file_name.get(),
                     action_display_order=default_file.action_display_order.get(),
                     visible_action_count=default_file.visible_action_count.get(),
                     is_edit=True
@@ -753,6 +962,9 @@ class DefaultTaskFiles(flow.DynamicMap):
         child.enabled.set(self._cache[child.name()]['enabled'])
         child.optional.set(self._cache[child.name()]['optional'])
         child.is_primary_file.set(self._cache[child.name()]['is_primary_file'])
+        child.use_base_file.set(self._cache[child.name()]['use_base_file'])
+        child.from_task.set(self._cache[child.name()]['from_task'])
+        child.base_file_name.set(self._cache[child.name()]['base_file_name'])
         child.action_display_order.set(self._cache[child.name()]['action_display_order'])
         child.visible_action_count.set(self._cache[child.name()]['visible_action_count'])
         child.is_edit.set(self._cache[child.name()]['is_edit'])
@@ -988,7 +1200,8 @@ class CreateKitsuTasksPage2(flow.Action):
                 t = self._mgr.default_tasks.add_default_task(
                     item.task_name.get().lower(),
                     item.task_name.get(),
-                    item.task_type.get().lower()
+                    item.task_type.get().lower(),
+                    0
                 )
                 t.kitsu_tasks.add(item.task_name.get(), 0)
             else:
@@ -1101,7 +1314,7 @@ class DefaultTasks(CustomEntityCollection):
     def mapped_type(cls):
         return DefaultTask
 
-    def add_default_task(self, name, display_name, template_name, position=-1, path_format=None, enabled=True, optional=False):
+    def add_default_task(self, name, display_name, template_name, position=-1, path_format=None, enabled=True, optional=False, icon=None):
         if position < 0:
             position = len(self)
         
@@ -1112,6 +1325,8 @@ class DefaultTasks(CustomEntityCollection):
         dt.path_format.set(path_format)
         dt.enabled.set(enabled)
         dt.optional.set(optional)
+        if icon:
+            dt.icon.set(icon)
         
         self.touch()
         return dt
@@ -1469,23 +1684,27 @@ class TaskManager(flow.Object):
 
     def get_task_files(self, task_name, enabled_only=False):
         """
-        Returns a list of tuples describing the default files
+        Returns a dict describing the default files
         of a task with the given name.
         
-        Tuples follow the layout (<file name>, <path format>).
+        Each pair of the returned dict has the following layout:
+            <mapped_name>: (<display_name>, <path_format>, <optional>)
         """
-        files = []
+        files = {}
         if self.default_tasks.has_mapped_name(task_name):
             dt = self.default_tasks[task_name]
-            files = [
-                (
+            files = {
+                df.name(): (
                     df.file_name.get(),
                     df.path_format.get(),
                     df.optional.get(),
+                    df.use_base_file.get(),
+                    df.from_task.get(),
+                    df.base_file_name.get()
                 )
                 for df in dt.files.mapped_items()
                 if not enabled_only or df.enabled.get()
-            ]
+            }
         
         return files
     
