@@ -43,6 +43,7 @@ class RevisionData:
         self.links = None
         self.colors = None
         self.site_names = site_names
+        self.activate_oid = None
         
         self.update()
     
@@ -75,6 +76,7 @@ class RevisionData:
             )
             for name in self.site_names
         ]
+        self.activate_oid = self.session.cmds.Flow.call(self.oid, 'activate_oid', [], {})
     
     def sync_status(self, index):
         return self.statutes[index]
@@ -97,9 +99,10 @@ class FileData:
     Task file data to be used by the task view.
     '''
     
-    def __init__(self, session, oid, site_names, goto_oid=None, activate_oid=None, is_ref=False):
+    def __init__(self, session, oid, task_name, site_names, goto_oid=None, activate_oid=None, is_ref=False):
         self.session = session
         self.oid = oid
+        self.task_name = task_name
         self.label = None
         self.icon = None
         self.goto_oid = goto_oid
@@ -126,22 +129,16 @@ class FileData:
         self.update_actions()
     
     def update_actions(self):
-        display_order = self.session.cmds.Flow.get_value(self.oid+'/action_display_order') or {}
-        visible_count = self.session.cmds.Flow.get_value(self.oid+'/visible_action_count') or 0
-
-        # Sort actions by display priority
-        actions = sorted(
-            self.session.cmds.Flow.get_object_actions(self.oid),
-            key=lambda a: display_order.get(a[2][0], sys.maxsize)
-        )
+        mgr = self.session.cmds.Flow.call('/'.join(self.oid.split('/', 2)[:2]), 'get_task_manager', [], {})
+        main, secondary = self.session.cmds.Flow.call(mgr.oid(), 'get_file_priority_actions', [self.task_name, self.oid], {})
         
         self.main_actions = [
             ActionData(a[3]['oid'], a[3]['ui'])
-            for a in actions[:visible_count]
+            for a in main
         ]
         self.secondary_actions = [
             ActionData(a[3]['oid'], a[3]['ui'])
-            for a in actions[visible_count:]
+            for a in secondary
         ]
     
     def compute_history_data(self):
@@ -335,7 +332,7 @@ class TaskData:
     
     def create_file_data(self, oid, goto_oid=None, is_ref=False):
         activate_oid = self.session.cmds.Flow.call(oid, 'activate_oid', [], {}) or None
-        return FileData(self.session, oid, self.site_names, goto_oid, activate_oid, is_ref)
+        return FileData(self.session, oid, self.oid.split('/')[-1], self.site_names, goto_oid, activate_oid, is_ref)
     
     def remove_file_data(self, oid):
         _type, index = self.file_indexes[oid]
@@ -446,6 +443,10 @@ class Controller:
         
         self.task_widget.view.file_lists.endResetModels()
         self.task_widget.view.file_lists.updateLists()
+
+    def handle_dropped_files(self, paths):
+        self.session.cmds.Flow.set_value('/'+self.oid.split('/')[1]+'/import_files/paths', paths)
+        self.show_action_dialog('/'+self.oid.split('/')[1]+'/import_files')
     
     def create_refs(self, oids, file_type):
         valid_oids = [
@@ -580,7 +581,15 @@ class Controller:
     
     def site_count(self):
         return len(self.site_names) + 1
-    
+
+    def is_bookmarked(self):
+        return self.session.cmds.Flow.call(
+            self.oid + '/toggle_bookmark', 'is_bookmarked', [], {}
+        )
+
+    def toggle_bookmark(self):
+        self.session.cmds.Flow.run_action(oid=self.oid + '/toggle_bookmark', button='Toggle')
+
     def show_action_dialog(self, action_oid):
         self.task_widget.page.show_action_dialog(action_oid)
     
