@@ -133,6 +133,7 @@ class FileHistoryView(QtWidgets.QTableView):
         self.action_menu = QtWidgets.QMenu()
 
         self.customContextMenuRequested.connect(self._on_context_menu_requested)
+        self.doubleClicked.connect(self._on_item_double_clicked)
     
     def set_show_statutes(self, checked):
         if checked:
@@ -201,6 +202,14 @@ class FileHistoryView(QtWidgets.QTableView):
 
         if actions:
             self.action_menu.exec_(self.viewport().mapToGlobal(pos))
+    
+    def _on_item_double_clicked(self, index):
+        data = self.controller.selected_file_revision_data(index.row())
+        
+        if data.activate_oid is None:
+            self.controller.goto(data.oid)
+        else:
+            self.controller.show_action_dialog(data.activate_oid)
 
 
 class FileStatutesView(QtWidgets.QTableView):
