@@ -4,6 +4,9 @@ import getpass
 import fnmatch
 
 from kabaret import flow
+from kabaret.flow_entities.entities import PropertyValue, Property
+
+from ..utils.kabaret.flow_entities.entities import CustomEntity, CustomEntityCollection
 
 
 class MyBookmarks(flow.DynamicMap):
@@ -384,9 +387,13 @@ class UserPreferences(flow.Object):
     option_presets = flow.Child(OptionPresets)
 
 
-class UserStatus(flow.values.ChoiceValue):
+class UserStatus(PropertyValue):
 
     CHOICES = ["User", "Admin", "Supervisor"]
+    DEFAULT_EDITOR = 'choice'
+
+    def choices(self):
+        return self.__class__.CHOICES
 
 
 class SessionUserStatus(flow.values.SessionValue):
@@ -422,24 +429,24 @@ class AddUserAction(flow.Action):
         self._users.touch()
 
 
-class User(flow.Object):
+class User(CustomEntity):
 
     ICON = ("icons.gui", "user")
 
-    login  = flow.Param().watched()
-    status = flow.Param("User", UserStatus).ui(editable=False)
+    login  = Property()
+    code   = Property()
+    status = Property(UserStatus).ui(editable=False)
 
     bookmarks = flow.Child(UserBookmarks)
     preferences = flow.Child(UserPreferences)
 
     _map = flow.Parent()
 
-    def child_value_changed(self, child_value):
-        if child_value is self.login:
-            self._map.set_user_login(self.name(), self.login.get())
+    def get_code(self):
+        return self.code.get() or self.name()
 
 
-class Users(flow.Map):
+class Users(CustomEntityCollection):
 
     ICON = ("icons.gui", "team")
     STYLE_BY_STATUS = {
@@ -450,9 +457,6 @@ class Users(flow.Map):
 
     add_user_action = flow.Child(AddUserAction).ui(label="Add user")
 
-    _name_by_uid = flow.HashParam()
-    _mapped_name_per_login = flow.HashParam() # Allow to retrieve users by their logins
-
     @classmethod
     def mapped_type(cls):
         return flow.injection.injectable(User)
@@ -468,24 +472,28 @@ class Users(flow.Map):
         user = self.add(name)
         user.status.set(status)
         user.login.set(login)
-        self.set_user_login(name, login)
 
         return user
     
     def remove_user(self, name):
         self.remove(name)
-        self._mapped_name_per_login.del_key(name)
     
     def get_user(self, login):
-        if not self._mapped_name_per_login.has_key(login):
+        '''
+        Returns the user with the given authentication login.
+        '''
+        user_data = (
+            self.get_entity_store()
+            .get_collection(self.collection_name())
+            .find_one(
+                {'login': login},
+                {'name': 1}
+            )
+        )
+        if user_data is None:
             return None
         
-        name = self._mapped_name_per_login.get_key(login)
-        return self.get_mapped(name)
-    
-    def set_user_login(self, mapped_name, login):
-        u = self.get_mapped(mapped_name)
-        self._mapped_name_per_login.set_key(login, mapped_name)
+        return self.get_mapped(user_data['name'])
 
     def _fill_row_cells(self, row, item):
         row["ID"] = item.name()
